{% extends "admin/base_site.html" %}
{% load admin_static admin_list i18n %}
{% load url from future %}
{% load crispy_forms_tags %}


{% block extrastyle %}
  {{ block.super }}
  <link rel="stylesheet" type="text/css" href="{% static 'admin/css/changelists.css' %}" />
  <link rel="stylesheet" type="text/css" href="{% static 'admin/css/forms.css' %}" />
  {{ media.css }}
  <style>
    #result_list .changed {
          background-color: #ffc;
    }
    #changelist table thead th .text {
      padding: 2px 5px;
    }
    #changelist table tbody td:first-child {
        text-align: left;
    }
    #changelist-form ul.errorlist {
      margin: 0 !important;
    }
    .help {
        font-weight: normal !important;
  }
  </style>
{% endblock %}

{% block extrahead %}
{% url 'admin:jsi18n' as jsi18nurl %}
<script type="text/javascript" src="{{ jsi18nurl|default:'../../jsi18n/' }}"></script>
{{ block.super }}
{{ media.js }}
{% endblock %}

{% block bodyclass %}change-list{% endblock %}

{% block content %}
  <div id="content-main">
    <div class="module" id="changelist">
        <form id="changelist-form" action="" method="post">{% csrf_token %}
            {% crispy form %}
            <input type="submit" name="_save" class="form-group btn-default" value="{% trans 'Save' %}"/>
        </form>
    </div>
  </div>
{% endblock %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ app_label|capfirst|escape }}</a>
&rsaquo; {{ opts.verbose_name_plural|capfirst }}
</div>
{% endblock %}